package com.example.nto.service.impl;

import com.example.nto.dto.EmployeeDTO;
import com.example.nto.dto.RegisterDTO;
import com.example.nto.entity.Employee;
import com.example.nto.exceptions.EmployeeAlreadyExistException;
import com.example.nto.repository.EmployeeRepository;
import com.example.nto.service.EmployeeService;
import com.example.nto.util.EmployeeMapper;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.Optional;

@Service
@AllArgsConstructor
public class EmployeeServiceImpl implements EmployeeService {
    private EmployeeRepository repository;
    @Override
    public void updateLocalTime(Employee employee) {
        employee.setLastVisit(LocalDateTime.now().toString());
        repository.save(employee);
    }

    @Override
    public Employee findEmployeeByLogin(String login) {

        return repository.findEmployeeByLogin(login).get();
    }

    @Override
    public EmployeeDTO createEmployee(RegisterDTO dto) {

        Optional<Employee> optionalEmployee = repository.findEmployeeByLogin(dto.getUsername());
        if(optionalEmployee.isPresent()){
            throw new EmployeeAlreadyExistException("Employee with username " + dto.getUsername() +" already exist");
        }

        Employee employee = new Employee();
        employee.setName(dto.getName());
        employee.setLogin(dto.getUsername());
        employee.setPassword(dto.getPassword());
        employee.setPhoto(dto.getPhoto());
        employee.setPosition(dto.getPosition());
        employee.setLastVisit(LocalDateTime.now().toString());

        return EmployeeMapper.convertToDTO(repository.save(employee));
    }


}

